var documenterSearchIndex = {"docs":
[{"location":"api/#API","page":"API","title":"API","text":"","category":"section"},{"location":"api/#Load-a-Dataset","page":"API","title":"Load a Dataset","text":"","category":"section"},{"location":"api/","page":"API","title":"API","text":"To get data from a supported dataset, you only need one function: ","category":"page"},{"location":"api/","page":"API","title":"API","text":"dataset(name::AbstractString, inputdir::AbstractString, outputdir::AbstractString)\nBase.summary(dataset::SpeechDataset)\nget_dataset_kwargs(name::String)\n","category":"page"},{"location":"api/#SpeechDatasets.dataset-Tuple{AbstractString, AbstractString, AbstractString}","page":"API","title":"SpeechDatasets.dataset","text":"dataset(name::AbstractString, inputdir::AbstractString, outputdir::AbstractString; <keyword arguments>)\n\nExtract recordings and annotations for desired dataset.\n\nReturn a SpeechDataset object.\n\nCreate the outputdir folder, with:\n\nrecordings.jsonl containing each audio file path and associated metadata\nannotations-<subset>.jsonl containing each annotation and associated metadata\n\nArguments\n\nname Name of the dataset. Supported names are [\"AVID\", \"INA Diachrony\", \"Mini LibriSpeech\", \"Multilingual LibriSpeech\", \"TIMIT\", \"Speech2Tex\"].\ninputdir Name of dataset directory. If the directory does not exists, it is created and the data is downloaded if possible. Not all datasets can be downloaded, for example proprietary datasets does not implements a download function.\noutputdir is the output directory for manifest files.\n\nKeyword Arguments\n\nCommon kwargs are\n\nsubset Part of the dataset to load (for example \"train\" or \"test\").\nlang ISO 639-3 code of the language.\n\nOther kwargs can be available depending on the dataset, they can be accessed with get_dataset_kwargs(name::String).\n\n\n\n\n\n","category":"method"},{"location":"api/#Base.summary-Tuple{SpeechDataset}","page":"API","title":"Base.summary","text":"Base.summary(dataset::SpeechDataset)\n\nDisplay informations about given SpeechDataset\n\n\n\n\n\n","category":"method"},{"location":"api/#SpeechDatasets.get_dataset_kwargs-Tuple{String}","page":"API","title":"SpeechDatasets.get_dataset_kwargs","text":"get_dataset_kwargs(name::String)\n\nReturn a NamedTuple containing each supported kwarg and its default value for a dataset identified by name.\n\n\n\n\n\n","category":"method"},{"location":"api/#Types","page":"API","title":"Types","text":"","category":"section"},{"location":"api/#SpeechDataset","page":"API","title":"SpeechDataset","text":"","category":"section"},{"location":"api/","page":"API","title":"API","text":"SpeechDatasetInfos\nSpeechDatasetInfos(name::AbstractString)\nSpeechDataset\nSpeechDataset(infos::SpeechDatasetInfos, manifestroot::AbstractString, subset::AbstractString)","category":"page"},{"location":"api/#SpeechDatasets.SpeechDatasetInfos","page":"API","title":"SpeechDatasets.SpeechDatasetInfos","text":"struct SpeechDatasetInfos\n\nStore metadata about a dataset.\n\nFields\n\nname Dataset official name\nlang Language or list of languages (ISO 639-3 code)\nlicense License name\nsource URL to the dataset publication or content\nauthors list of authors\ndescription A few sentences describing the content or main purpose \nsubsets List of available subsets (for example [\"train\", \"test\"])\n\n\n\n\n\n","category":"type"},{"location":"api/#SpeechDatasets.SpeechDatasetInfos-Tuple{AbstractString}","page":"API","title":"SpeechDatasets.SpeechDatasetInfos","text":"SpeechDatasetInfos(name::AbstractString)\n\nConstruct a SpeechDatasetInfos from the Dataset name.\n\n\n\n\n\n","category":"method"},{"location":"api/#SpeechDatasets.SpeechDataset","page":"API","title":"SpeechDatasets.SpeechDataset","text":"struct SpeechDataset <: MLUtils.AbstractDataContainer\n\nStore all dataset recordings and annotations. \n\nIt can be iterated, and will give a Tuple{Recording, Annotation} for each entry. Indexation can be done with integer or id.\n\nFields\n\ninfos::SpeechDatasetInfos\nidxs::Vector{AbstractString} id indexes to access elements\nannotations::Dict{AbstractString, Annotation} Annotation for each index\nrecordings::Dict{AbstractString, Recording} Recording for each index\n\n\n\n\n\n","category":"type"},{"location":"api/#SpeechDatasets.SpeechDataset-Tuple{SpeechDatasetInfos, AbstractString, AbstractString}","page":"API","title":"SpeechDatasets.SpeechDataset","text":"SpeechDataset(infos::SpeechDatasetInfos, manifestroot::AbstractString, subset::AbstractString)\n\nCreate a SpeechDataset from manifest files and subset.\n\n\n\n\n\n","category":"method"},{"location":"api/","page":"API","title":"API","text":"Access a single element with integer or id indexing","category":"page"},{"location":"api/","page":"API","title":"API","text":"# ds::SpeechDataset\nds[1]\nds[\"1988-147956-0027\"]","category":"page"},{"location":"api/","page":"API","title":"API","text":"Access several elements by providing a list","category":"page"},{"location":"api/","page":"API","title":"API","text":"ds[[1,4,7]]\nds[[8, 2, \"777-126732-0015\"]]","category":"page"},{"location":"api/","page":"API","title":"API","text":"Get all annotations","category":"page"},{"location":"api/","page":"API","title":"API","text":"ds.annotations","category":"page"},{"location":"api/#Manifest-items","page":"API","title":"Manifest items","text":"","category":"section"},{"location":"api/","page":"API","title":"API","text":"SpeechDatasets.ManifestItem\nRecording\nAnnotation\nAudioSources.load(r::Recording; start = -1, duration = -1, channels = r.channels)\nAudioSources.load(r::Recording, a::Annotation)\nSpeechDatasets.load_manifest(T::Type{<:Union{Recording, Annotation}}, path)","category":"page"},{"location":"api/#SpeechDatasets.ManifestItem","page":"API","title":"SpeechDatasets.ManifestItem","text":"abstract type ManifestItem end\n\nBase class for all manifest item. Every manifest item should have an id attribute.\n\n\n\n\n\n","category":"type"},{"location":"api/#SpeechDatasets.Recording","page":"API","title":"SpeechDatasets.Recording","text":"struct Recording{Ts<:AbstractAudioSource} <: ManifestItem\n    id::AbstractString\n    source::Ts\n    channels::Vector{Int}\n    samplerate::Int\nend\n\nA recording is an audio source associated with and id.\n\nConstructors\n\nRecording(id, source, channels, samplerate)\nRecording(id, source[; channels = missing, samplerate = missing])\n\nIf the channels or the sample rate are not provided then they will be read from source.\n\nwarning: Warning\nWhen preparing large corpus, not providing the channels and/or the sample rate can drastically reduce the speed as it forces to read source.\n\n\n\n\n\n","category":"type"},{"location":"api/#SpeechDatasets.Annotation","page":"API","title":"SpeechDatasets.Annotation","text":"struct Annotation <: ManifestItem\n    id::AbstractString\n    recording_id::AbstractString\n    start::Float64\n    duration::Float64\n    channel::Union{Vector, Colon}\n    data::Dict\nend\n\nAn \"annotation\" defines a segment of a recording on a single channel. The data field is an arbitrary dictionary holdin the nature of the annotation. start and duration (in seconds) defines, where the segment is locatated within the recoding recording_id.\n\nConstructor\n\nAnnotation(id, recording_id, start, duration, channel, data)\nAnnotation(id, recording_id[; channel = missing, start = -1, duration = -1, data = missing)\n\nIf start and/or duration are negative, the segment is considered to be the whole sequence length of the recording.\n\n\n\n\n\n","category":"type"},{"location":"api/#AudioSources.load-Tuple{Recording}","page":"API","title":"AudioSources.load","text":"load(recording::Recording [; start = -1, duration = -1, channels = recording.channels])\nload(recording, annotation)\n\nLoad the signal from a recording. start, duration (in seconds)\n\nThe function returns a tuple (x, sr) where x is a NC array \n\nN is the length of the signal and C is the number of channels\nand sr is the sampling rate of the signal.\n\n\n\n\n\n","category":"method"},{"location":"api/#AudioSources.load-Tuple{Recording, Annotation}","page":"API","title":"AudioSources.load","text":"load(r::Recording, a::Annotation)\nload(t::Tuple{Recording, Annotation})\n\nLoad only a segment of the recording referenced in the annotation.\n\n\n\n\n\n","category":"method"},{"location":"api/#SpeechDatasets.load_manifest-Tuple{Type{<:Union{Annotation, Recording}}, Any}","page":"API","title":"SpeechDatasets.load_manifest","text":"load_manifest(Annotation, path)\nload_manifest(Recording, path)\n\nLoad Recording/Annotation manifest from path.\n\n\n\n\n\n","category":"method"},{"location":"api/#Lexicons","page":"API","title":"Lexicons","text":"","category":"section"},{"location":"api/","page":"API","title":"API","text":"CMUDICT(path)\nTIMITDICT(timitdir)\nMFAFRDICT(path)","category":"page"},{"location":"api/#SpeechDatasets.CMUDICT-Tuple{Any}","page":"API","title":"SpeechDatasets.CMUDICT","text":"CMUDICT(path)\n\nReturn the dictionary of pronunciation loaded from the CMU sphinx dictionary. The CMU dictionary will be donwloaded and stored into to path. Subsequent calls will only read the file path without downloading again the data.\n\n\n\n\n\n","category":"method"},{"location":"api/#SpeechDatasets.TIMITDICT-Tuple{Any}","page":"API","title":"SpeechDatasets.TIMITDICT","text":"TIMITDICT(timitdir)\n\nReturn the dictionary of pronunciation as provided by TIMIT corpus (located in timitdir).\n\n\n\n\n\n","category":"method"},{"location":"api/#SpeechDatasets.MFAFRDICT-Tuple{Any}","page":"API","title":"SpeechDatasets.MFAFRDICT","text":"MFAFRDICT(path)\n\nReturn the french dictionary of pronunciation as provided by MFA (french_mfa v2.0.0a).\n\n\n\n\n\n","category":"method"},{"location":"api/#Index","page":"API","title":"Index","text":"","category":"section"},{"location":"api/","page":"API","title":"API","text":"","category":"page"},{"location":"newdataset/#Add-a-new-dataset","page":"Add a new dataset","title":"Add a new dataset","text":"","category":"section"},{"location":"newdataset/","page":"Add a new dataset","title":"Add a new dataset","text":"Add metadatas in src/corpora/corpora.json  \nExample:\n {\n     \"name\": \"TIMIT\",\n     \"lang\": \"eng\",\n     \"license\": \"LDC User Agreement for Non-Members\",\n     \"source\": \"https://catalog.ldc.upenn.edu/LDC93S1\",\n     \"authors\": [\"John S. Garofolo\", \"Lori F. Lamel\", \"William M. Fisher\", \"Jonathan G. Fiscus\", \"David S. Pallett\", \"Nancy L. Dahlgren\", \"Victor Zue\"],\n     \"description\": \"The TIMIT corpus of read speech has been designed to provide speech data for the acquisition of acoustic-phonetic knowledge and for the development and evaluation of automatic speech recognition systems.\",\n     \"subsets\": [\"train\", \"dev\", \"test\"]\n },\nCreate a new .jl file in src/corpora\nAdd the following line at the beginning of the file:  \n const <idname> = get_nametype(<dataset name>)\nReplace <idname> with an identifier of your dataset (for example, timit_id).\nReplace <dataset name> with a string containing the name of the dataset (same as referenced in corpora.json).\nIf your dataset is downloadable, you can implement\n Base.download(::DatasetBuilder{<idname>}, dir::AbstractString)\nIt is mandatory to implement the prepare() function as such: \n prepare(::DatasetBuilder{<idname>}, inputdir, outputdir; <keyword arguments>)\nYou can add any keyword argument.    This function must create the following files in outputdir:\nrecordings.jsonl\nannotations.jsonl or annotations-<subset>.jsonl for each subset","category":"page"},{"location":"newdataset/","page":"Add a new dataset","title":"Add a new dataset","text":"That's it, you can now use ","category":"page"},{"location":"newdataset/","page":"Add a new dataset","title":"Add a new dataset","text":"dataset(\"name\", inputdir, outputdir; <keyword arguments>)","category":"page"},{"location":"newdataset/#DatasetBuilder-and-utilities","page":"Add a new dataset","title":"DatasetBuilder and utilities","text":"","category":"section"},{"location":"newdataset/","page":"Add a new dataset","title":"Add a new dataset","text":"DatasetBuilder\nDatasetBuilder(name::Symbol)\nSpeechDatasets.declareBuilder(name::Symbol)\nget_kwargs(func_name::Function, args_types::Tuple)\nget_nametype(name::String)\nBase.download\nprepare","category":"page"},{"location":"newdataset/#SpeechDatasets.DatasetBuilder","page":"Add a new dataset","title":"SpeechDatasets.DatasetBuilder","text":"struct DatasetBuilder{name}\n\nAllow to dispatch main dataset functions (download(), prepare()).   \n\nParameter\n\nname Dataset identifier\n\nFields\n\nkwargs::NamedTuple Keyword arguments supported by the dataset associated to name\n\n\n\n\n\n","category":"type"},{"location":"newdataset/#SpeechDatasets.DatasetBuilder-Tuple{Symbol}","page":"Add a new dataset","title":"SpeechDatasets.DatasetBuilder","text":"DatasetBuilder(name::Symbol)\n\nConstruct a DatasetBuilder for a given name. Implementations for each name are done by calling declareBuilder(name) (automatically done for each supported name).\n\n\n\n\n\n","category":"method"},{"location":"newdataset/#SpeechDatasets.declareBuilder-Tuple{Symbol}","page":"Add a new dataset","title":"SpeechDatasets.declareBuilder","text":"declareBuilder(name::Symbol)\n\nDeclare a functor for a DatasetBuilder of type name.\n\nA DatasetBuilder{name} object can now be created, and will hold the supported kwargs for the corresponding dataset.\n\n\n\n\n\n","category":"method"},{"location":"newdataset/#SpeechDatasets.get_kwargs-Tuple{Function, Tuple}","page":"Add a new dataset","title":"SpeechDatasets.get_kwargs","text":"get_kwargs(func_name::Function, args_types::Tuple)\n\nReturn a NamedTuple containing each supported kwarg and its default value for a given method.\n\nArguments\n\nfunc_name is the name of the function\nargs_types is a tuple of argument types for the desired method\n\n\n\n\n\n","category":"method"},{"location":"newdataset/#SpeechDatasets.get_nametype-Tuple{String}","page":"Add a new dataset","title":"SpeechDatasets.get_nametype","text":"get_nametype(name::String)\n\nReturn a symbol corresponding to the name. This symbol is used to identify the dataset.\n\n\n\n\n\n","category":"method"},{"location":"newdataset/#Base.download","page":"Add a new dataset","title":"Base.download","text":"Base.download(builder::DatasetBuilder{name}, dir::AbstractString)\n\nDownload the dataset identified by name into dir.\n\nEach dataset has its own implementation if download is supported (for example, a proprietary dataset might not implements download).\n\n\n\n\n\n","category":"function"},{"location":"newdataset/#SpeechDatasets.prepare","page":"Add a new dataset","title":"SpeechDatasets.prepare","text":"prepare(::DatasetBuilder{name}, inputdir, outputdir; <keyword arguments>)\n\nCreate manifest files into outputdir from dataset in inputdir. \n\nEach dataset has its own implementation, and can have optional keyword arguments, they can be accessed with get_dataset_kwargs(name::String).\n\nImplementing this function is mandatory for a dataset to be compatible with dataset()\n\n\n\n\n\n","category":"function"},{"location":"examples/#Examples","page":"Examples","title":"Examples","text":"","category":"section"},{"location":"examples/","page":"Examples","title":"Examples","text":"using SpeechDatasets\nds = dataset(\"Mini LibriSpeech\", \"path/to/minils\", \"minils_output\")\ntypeof(ds[26])","category":"page"},{"location":"examples/","page":"Examples","title":"Examples","text":"println(\"Tuple{Recording, Annotation}\") # hide","category":"page"},{"location":"installation/#Installation","page":"Installation","title":"Installation","text":"","category":"section"},{"location":"installation/","page":"Installation","title":"Installation","text":"This package is part of the PTAL tool collection and requires the PTAL registry to be installed.","category":"page"},{"location":"installation/","page":"Installation","title":"Installation","text":"To add this registry to your Julia installation type ] to enter the package mode of the REPL and then type:","category":"page"},{"location":"installation/","page":"Installation","title":"Installation","text":"pkg> registry add \"https://gitlab.lisn.upsaclay.fr/PTAL/Registry\"","category":"page"},{"location":"installation/","page":"Installation","title":"Installation","text":"Once the registry has been added, SpeechDatasets can be installed with the Julia package manager by typing in Pkg REPL mode","category":"page"},{"location":"installation/","page":"Installation","title":"Installation","text":"pkg> add SpeechDatasets","category":"page"},{"location":"#SpeechDatasets.jl","page":"Home","title":"SpeechDatasets.jl","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"Convenient and unified way to load a speech dataset. It can then be harnessed with other PTAL tools.  ","category":"page"},{"location":"","page":"Home","title":"Home","text":"A SpeechDataset instance consists of a set of recordings (info about audio data) and annotations.","category":"page"},{"location":"#Contents","page":"Home","title":"Contents","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"Pages = [\"index.md\", \"installation.md\", \"examples.md\", \"api.md\", \"datasets.md\", \"newdataset.md\"]","category":"page"},{"location":"#License","page":"Home","title":"License","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"This software is provided under the CeCILL-C license","category":"page"},{"location":"#Authors","page":"Home","title":"Authors","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"Lucas Ondel Yang\nNicolas Denier\nSimon Devauchelle","category":"page"},{"location":"","page":"Home","title":"Home","text":"(Image: )","category":"page"},{"location":"datasets/#Supported-Datasets","page":"Supported datasets","title":"Supported Datasets","text":"","category":"section"},{"location":"datasets/","page":"Supported datasets","title":"Supported datasets","text":"using SpeechDatasets, JSON, Markdown\ncorpora_infos = JSON.parsefile(SpeechDatasets.corpora_file)\n\nfunction write_corpora_docs(io::IO)\n    for corpus in corpora_infos\n        fields = keys(corpus)\n        println(io, \"## $(corpus[\"name\"])\")\n\n        if \"license\" in fields\n            license = replace(corpus[\"license\"], \"-\" => \"--\") # dash are escaped\n            color = license==\"proprietary\" ? \"red\" : \"lightblue\"\n            license_badge = \"https://img.shields.io/badge/License-$license-$color\"\n            println(io, \"![License]($license_badge)\")\n        end\n\n        if \"lang\" in fields\n            languages = corpus[\"lang\"] isa String ? [corpus[\"lang\"]] : corpus[\"lang\"]\n            for lang in languages\n                lang_badge = \"https://img.shields.io/badge/Lang-$lang-lightgreen\"\n                println(io, \"![Language]($lang_badge)\")\n            end\n        end\n\n        if \"description\" in fields\n            println(io, \"\")\n            println(io, corpus[\"description\"])\n        end\n\n        if \"source\" in fields\n            println(io, \"\")\n            println(io, \"[Source]($(corpus[\"source\"]))\")\n        end\n\n        if \"authors\" in fields\n            println(io, \"\")\n            println(io, \"### Authors\")\n            println(io, join(corpus[\"authors\"], \", \"))\n        end\n\n        need_subset = false\n        if \"subsets\" in fields\n            need_subset = true\n            println(io, \"\")\n            println(io, \"### Subsets\")\n            println(io, join(corpus[\"subsets\"], \", \"))\n        end\n\n        kwargs = get_dataset_kwargs(corpus[\"name\"])\n        if need_subset \n            kwargs = merge(kwargs, (;subset=\"\"))\n        end\n        if ! isempty(kwargs)\n            println(io, \"### Keyword arguments\")\n            println(io, \"```julia\")\n            println(io, kwargs)\n            println(io, \"```\")\n        end\n\n        println(io, \"\\n---\")\n    end\nend\n\nMarkdown.parse(sprint(write_corpora_docs))","category":"page"}]
}
